list property

List<NodeInput> list
final

Graph source defined as list of NodeInput's. Root or entry point for graph is selected as first found node without incomes or the first node in the list if there's no nodes without incomes.

Implementation

final List<NodeInput> list;