nodeBuilder property
Builder function to render custom node Widget. Fires upon each node build call and provides info about node as MatrixNode.
Implementation
final NodeCellBuilder? nodeBuilder;
Builder function to render custom node Widget. Fires upon each node build call and provides info about node as MatrixNode.
final NodeCellBuilder? nodeBuilder;