contactEdgesDistance property
Distance between backward and forward oriented edge when they enter the same node. Defaults to 5.0. Set it to zero if you need to center all edges entry points.
Implementation
final double contactEdgesDistance;
Distance between backward and forward oriented edge when they enter the same node. Defaults to 5.0. Set it to zero if you need to center all edges entry points.
final double contactEdgesDistance;